#!/bin/sh
echo 'name: conduit
version: 1.0.5
id: conduit-1.0.5-960035d936621178a72ea77b62586809

license: BSD3
copyright:
maintainer: michael@snoyman.com
stability:
homepage: http://github.com/snoyberg/conduit
package-url:
synopsis: Streaming data processing library.
description: @conduit@ is a solution to the streaming data problem, allowing for production, transformation, and consumption of streams of data in constant memory. It is an alternative to lazy I\/O which guarantees deterministic resource handling, and fits in the same general solution space as @enumerator@\/@iteratee@ and @pipes@. For a tutorial, please visit <https://haskell.fpcomplete.com/user/snoyberg/library-documentation/conduit-overview>.
             .
             Release history:
             .
             [1.0] Simplified the user-facing interface back to the Source, Sink, and Conduit types, with Producer and Consumer for generic code. Error messages have been simplified, and optional leftovers and upstream terminators have been removed from the external API. Some long-deprecated functions were finally removed.
             .
             [0.5] The internals of the package are now separated to the .Internal module, leaving only the higher-level interface in the advertised API. Internally, switched to a @Leftover@ constructor and slightly tweaked the finalization semantics.
             .
             [0.4] Inspired by the design of the pipes package: we now have a single unified type underlying @Source@, @Sink@, and @Conduit@. This type is named @Pipe@. There are type synonyms provided for the other three types. Additionally, @BufferedSource@ is no longer provided. Instead, the connect-and-resume operator, @$$+@, can be used for the same purpose.
             .
             [0.3] ResourceT has been greatly simplified, specialized for IO, and moved into a separate package. Instead of hard-coding ResourceT into the conduit datatypes, they can now live around any monad. The Conduit datatype has been enhanced to better allow generation of streaming output. The SourceResult, SinkResult, and ConduitResult datatypes have been removed entirely.
             .
             [0.2] Instead of storing state in mutable variables, we now use CPS. A @Source@ returns the next @Source@, and likewise for @Sink@s and @Conduit@s. Not only does this take better advantage of GHC\'\''s optimizations (about a 20% speedup), but it allows some operations to have a reduction in algorithmic complexity from exponential to linear. This also allowed us to remove the @Prepared@ set of types. Also, the @State@ functions (e.g., @sinkState@) use better constructors for return types, avoiding the need for a dummy state on completion.
             .
             [0.1] @BufferedSource@ is now an abstract type, and has a much more efficient internal representation. The result was a 41% speedup on microbenchmarks (note: do not expect speedups anywhere near that in real usage). In general, we are moving towards @BufferedSource@ being a specific tool used internally as needed, but using @Source@ for all external APIs.
             .
             [0.0] Initial release.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules: Data.Conduit Data.Conduit.Binary Data.Conduit.Text
                 Data.Conduit.List Data.Conduit.Lazy Data.Conduit.Internal
                 Data.Conduit.Util
hidden-modules: System.PosixFile
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.6.3/conduit-1.0.5
library-dirs: /usr/local/lib/cabal/ghc-7.6.3/conduit-1.0.5
              /usr/local/lib
hs-libraries: HSconduit-1.0.5
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.6.0.1-2324e29e8f7c561043683fccde7728aa
         bytestring-0.10.0.2-eecc198ed81abb69aaded5c195068445
         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
         directory-1.2.0.1-993cd73de8286c92ca288a1093da3273
         lifted-base-0.2.0.5-5ed3b97f0b001072c69c352af4420136
         mmorph-1.0.0-a15fab14847b17e8633f502cec662879
         monad-control-0.3.2.1-cd3926c42bd672ee51d1cd15cf675e99
         resourcet-0.4.7.1-7b99f9be07486e6364edadf2b4c82ccb
         text-0.11.3.1-e3fd09aac6fbf908855282746125e0ed
         transformers-0.3.0.0-948c0bbaafc952a144be4248ffa27cb1
         transformers-base-0.4.1-29e41c74cf8cb797697c0a8da0a90a5c
         void-0.6-bfa8bcec991f9caee4dbdf54caf44448
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.6.3/conduit-1.0.5/html/conduit.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.6.3/conduit-1.0.5/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
